C Copyright 1981-2012 ECMWF.
C
C This software is licensed under the terms of the Apache Licence 
C Version 2.0 which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
C
C In applying this licence, ECMWF does not waive the privileges and immunities 
C granted to it by virtue of its status as an intergovernmental organisation 
C nor does it submit to any jurisdiction.
C
      INTEGER QG08018(80)
      DATA QG08018/
     X  18 ,  25 ,  36 ,  40,
     X  45 ,  54 ,  60 ,  64,
     X  72 ,  72 ,  80 ,  90,
     X  96 , 100 , 108 , 120,
     X 120 , 128 , 135 , 144,
     X 144 , 150 , 160 , 160,
     X 180 , 180 , 180 , 192,
     X 192 , 200 , 200 , 216,
     X 216 , 216 , 225 , 225,
     X 240 , 240 , 240 , 256,
     X 256 , 256 , 256 , 288,
     X 288 , 288 , 288 , 288,
     X 288 , 288 , 288 , 288,
     X 300 , 300 , 300 , 300,
     X 320 , 320 , 320 , 320,
     X 320 , 320 , 320 , 320,
     X 320 , 320 , 320 , 320,
     X 320 , 320 , 320 , 320,
     X 320 , 320 , 320 , 320,
     X 320 , 320 , 320 , 320 /
